# Categorizing Applications Using the TIME Framework with Tags
### On this page
  * [Getting Started with Azure Functions](https://help.sap.com/docs/leanix/ea/updating-tag-related-to-time-model#getting-started-with-azure-functions)
  * [Step 1: Prepare Your Environment](https://help.sap.com/docs/leanix/ea/updating-tag-related-to-time-model#step-1:-prepare-your-environment)
  * [Step 2: Create a Tag Group](https://help.sap.com/docs/leanix/ea/updating-tag-related-to-time-model#step-2:-create-a-tag-group)
  * [Step 3: Create a Webhook](https://help.sap.com/docs/leanix/ea/updating-tag-related-to-time-model#step-3:-create-a-webhook)
  * [Step 4: Set Azure Environment Variables](https://help.sap.com/docs/leanix/ea/updating-tag-related-to-time-model#step-4:-set-azure-environment-variables)


In this guide, you will learn how to update tags on applications using Azure Functions. Tags reflect the elements of the Gartner® TIME framework, which allows you to map and measure the business value of your applications.
The Gartner® TIME framework represents a 2x2 quadrant and is an acronym for Tolerate, Invest, Migrate, Eliminate. You can use the setup provided and add your own logic on top in order to implement the specific case where a Tag on Fact Sheet will be updated according to "Functional Fit" and "Technical Fit". For more information, see [Gartner® TIME Framework](https://help.sap.com/docs/leanix/ea/time?locale=en-US&state=PRODUCTION&version=CLOUD).
